/* SylFilter - a message filter
 *
 * Copyright (C) 2011 Hiroyuki Yamamoto
 * Copyright (C) 2011 Sylpheed Development Team
 */

#include <glib.h>

#include "libsylph/utils.h"

#ifdef G_OS_WIN32
#  include <windows.h>
#  include <wchar.h>
#  include <shlobj.h>
#endif

#include "filter-utils.h"

char *xfilter_utils_get_file_contents(const char *file)
{
	char *contents = NULL;

	g_return_val_if_fail(file != NULL, NULL);

	if (g_file_get_contents(file, &contents, NULL, NULL))
		return contents;
	else
		return NULL;
}

void xfilter_free_mem(void *mem)
{
	g_free(mem);
}

const char *xfilter_utils_get_home_dir(void)
{
	return get_home_dir();
}

const char *xfilter_utils_get_base_dir(void)
{
	return get_rc_dir();
}

int xfilter_utils_set_base_dir(const char *path)
{
	const char *tmpdir;

	if (xfilter_utils_mkdir(path) < 0)
		return -1;

	set_rc_dir(path);
	tmpdir = get_tmp_dir();
	if (tmpdir)
		xfilter_utils_mkdir(tmpdir);

	return 0;
}

static const char *xfilter_utils_get_appdata_dir(void)
{
#ifdef G_OS_WIN32
	static char *appdata_dir = NULL;

	if (appdata_dir)
		return appdata_dir;
	else {
		HRESULT hr;
		wchar_t path[MAX_PATH + 1];

		hr = SHGetFolderPathW(NULL, CSIDL_APPDATA, NULL, 0, path);
		if (hr == S_OK)
			appdata_dir = g_utf16_to_utf8(path, -1, NULL, NULL, NULL);
		else
			return g_get_home_dir();
	}

	return appdata_dir;
#else
	return g_get_home_dir();
#endif
}

const char *xfilter_utils_get_default_base_dir(void)
{
	static char *default_base_dir = NULL;

	if (default_base_dir)
		return default_base_dir;
	else {
		const char *parent;

		parent = xfilter_utils_get_appdata_dir();
		default_base_dir = g_strconcat(parent, G_DIR_SEPARATOR_S,
#ifdef G_OS_WIN32
					       "SylFilter"
#else
					       ".sylfilter"
#endif
					       , NULL);
	}

	return default_base_dir;
}

int xfilter_utils_mkdir(const char *path)
{
	if (is_dir_exist(path))
		return 0;

	return g_mkdir(path, 0700);
}
